/*--------------------------------------------------------------------
 System functions.

 This scripts handles various system functions, like toggling of some
 configuration options (crossfading for example), and temporary output
 in the song ticker (volume, seek, clicks on the player buttons).
--------------------------------------------------------------------*/

#include "../../../lib/std.mi"

Function setTempText(String txt);
Function emptyTempText();

Global Wac MainComp, Playlist;
Global Text Songticker;
Global Slider Volbar, Seeker, SeekGhost;
Global Timer Songtickertimer, Wobbler;
Global Int WobblerWay;

Class GuiObject HintObject;
Class ToggleButton HintToggleButton;

Global HintObject Play, Stop, Previous, Next, Pause, Thinger, Open, Eq, Ml, Pl;
Global HintToggleButton ToggleXFade, ToggleShuffle, ToggleRepeat, cToggleXFade, cToggleShuffle, cToggleRepeat;

System.onScriptUnloading() {
  delete Songtickertimer;
  delete Wobbler;
}

System.onScriptLoaded() {

  // Timers won't start until .start(); is called
  Songtickertimer = new Timer;
  Songtickertimer.setDelay(1000);

  // Get Main and playlist components
  MainComp = getWac("{3CBD4483-DC44-11d3-B608-000086340885}");
  Playlist = getWac("{45F3F7C1-A6F3-4EE6-A15E-125E92FC3F8D}");

  Layout mainnormal = getContainer("Main").getLayout("Normal");

  Group systemtoggles = getContainer("Main").getLayout("Normal").getObject("main.lcd");
  Group pbgroup = getContainer("Main").getLayout("Normal").getObject("main.playback");
 
  // Get buttons
  ToggleXFade = systemtoggles.getObject("xfade");
  ToggleShuffle = systemtoggles.getObject("shuffle");
  ToggleRepeat = systemtoggles.getObject("repeat");

  // Get songticker, Volbar & Seeker
  Songticker = systemtoggles.getObject("Songticker");

  // Get Various buttons
  Play = pbgroup.getObject("Play");
  Pause = pbgroup.getObject("Pause");
  Stop = pbgroup.getObject("Stop");
  Next = pbgroup.getObject("Next");
  Previous = pbgroup.getObject("Prev");
  Open = pbgroup.getObject("eject");

  // Set buttons status
  if (ToggleXFade != NULL && MainComp != NULL) ToggleXFade.setActivated(MainComp.sendCommand("get_crossfade_enabled", 0, 0,""));
  if (ToggleShuffle != NULL && Playlist != NULL) ToggleShuffle.setActivated(Playlist.sendCommand("get_shuffle", 0, 0,""));
  if (ToggleRepeat != NULL && Playlist != NULL) ToggleRepeat.setActivated(Playlist.sendCommand("get_repeat", 0, 0,""));
}

Songtickertimer.onTimer() {
  Songticker.setText("");
  stop();
}

HintToggleButton.onLeftButtonDown(int x, int y) {
  if (HintToggleButton == ToggleXFade) setTempText("Toggle crossfade");
  else if (HintToggleButton == ToggleRepeat) setTempText("Toggle repeat");
  else if (HintToggleButton == ToggleShuffle) setTempText("Toggle shuffle");
}

HintToggleButton.onLeftButtonUp(int x, int y) {
  emptyTempText();
}

HintToggleButton.onToggle(int onoff) {
  String cmd, txt;
  Wac dest;
  if (HintToggleButton == ToggleXFade) {
    cmd = "crossfade_enable";
    txt = "Crossfade";
    dest = MainComp;
  } else if (HintToggleButton == ToggleRepeat)  {
    cmd = "repeat";
    txt = "Repeat";
    dest = Playlist;
  } else if (HintToggleButton == ToggleShuffle) {
    cmd = "shuffle";
    txt = "Shuffle";
    dest = Playlist;
  }
  if (dest) {
    dest.sendCommand(cmd, onoff, 0,"");
    String s;
    if (onoff) s = "on"; else s = "off";
    setTempText(txt + " now " + s);
  }
}

HintObject.onLeftButtonDown(int x, int y) {
  if (HintObject == Play) setTempText("Play");
  else if (HintObject == Stop) setTempText("Stop");
  else if (HintObject == Pause) setTempText("Pause");
  else if (HintObject == Next) setTempText("Next");
  else if (HintObject == Previous) setTempText("Previous");
  else if (HintObject == Thinger) setTempText("Thinger");
  else if (HintObject == Open) setTempText("Open");
  else if (HintObject == Eq) setTempText("Equalizer");
  else if (HintObject == ML) setTempText("Media Library");
  else if (HintObject == Pl) setTempText("Playlist Editor");
}

HintObject.onLeftButtonUp(int x, int y) {
  emptyTempText();
}

setTempText(String txt) {
  Songtickertimer.stop();
  Songticker.setText(txt);
  Songtickertimer.start();
}

emptyTempText() {
  Songticker.setText("");
  Songtickertimer.stop();
}

Songticker.onNotify(String s1, String s2, int i1, int i2) {
  setTempText(s1);
}
